==> chaosmesh-model-6.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JVMChaosFluentImpl<A extends JVMChaosFluent<A>> extends BaseFluent<A> implements JVMChaosFluent<A>{
  public JVMChaosFluentImpl() {
  }
  public JVMChaosFluentImpl(JVMChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private JVMChaosSpecBuilder spec;
  private JVMChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public JVMChaosFluent.MetadataNested<A> withNewMetadata() {
    return new JVMChaosFluentImpl.MetadataNestedImpl();
  }
  public JVMChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new JVMChaosFluentImpl.MetadataNestedImpl(item);
  }
  public JVMChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public JVMChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public JVMChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public JVMChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public JVMChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(JVMChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new JVMChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public JVMChaosFluent.SpecNested<A> withNewSpec() {
    return new JVMChaosFluentImpl.SpecNestedImpl();
  }
  public JVMChaosFluent.SpecNested<A> withNewSpecLike(JVMChaosSpec item) {
    return new JVMChaosFluentImpl.SpecNestedImpl(item);
  }
  public JVMChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public JVMChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new JVMChaosSpecBuilder().build());
  }
  public JVMChaosFluent.SpecNested<A> editOrNewSpecLike(JVMChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public JVMChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public JVMChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(JVMChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new JVMChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public JVMChaosFluent.StatusNested<A> withNewStatus() {
    return new JVMChaosFluentImpl.StatusNestedImpl();
  }
  public JVMChaosFluent.StatusNested<A> withNewStatusLike(JVMChaosStatus item) {
    return new JVMChaosFluentImpl.StatusNestedImpl(item);
  }
  public JVMChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public JVMChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new JVMChaosStatusBuilder().build());
  }
  public JVMChaosFluent.StatusNested<A> editOrNewStatusLike(JVMChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    JVMChaosFluentImpl that = (JVMChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<JVMChaosFluent.MetadataNested<N>> implements JVMChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) JVMChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends JVMChaosSpecFluentImpl<JVMChaosFluent.SpecNested<N>> implements JVMChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(JVMChaosSpec item) {
      this.builder = new JVMChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new JVMChaosSpecBuilder(this);
    }
    JVMChaosSpecBuilder builder;
    public N and() {
      return (N) JVMChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends JVMChaosStatusFluentImpl<JVMChaosFluent.StatusNested<N>> implements JVMChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(JVMChaosStatus item) {
      this.builder = new JVMChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new JVMChaosStatusBuilder(this);
    }
    JVMChaosStatusBuilder builder;
    public N and() {
      return (N) JVMChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JVMChaosFluentImpl<A extends JVMChaosFluent<A>> extends BaseFluent<A> implements JVMChaosFluent<A>{
  public JVMChaosFluentImpl() {
  }
  public JVMChaosFluentImpl(JVMChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private JVMChaosSpecBuilder spec;
  private JVMChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public JVMChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new JVMChaosFluentImpl.MetadataNestedImpl();
  }
  public JVMChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new JVMChaosFluentImpl.MetadataNestedImpl(item);
  }
  public JVMChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public JVMChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public JVMChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public JVMChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public JVMChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(JVMChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new JVMChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public JVMChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new JVMChaosFluentImpl.SpecNestedImpl();
  }
  public JVMChaosFluentImpl.SpecNested<A> withNewSpecLike(JVMChaosSpec item) {
    return new JVMChaosFluentImpl.SpecNestedImpl(item);
  }
  public JVMChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public JVMChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new JVMChaosSpecBuilder().build());
  }
  public JVMChaosFluentImpl.SpecNested<A> editOrNewSpecLike(JVMChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public JVMChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public JVMChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(JVMChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new JVMChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public JVMChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new JVMChaosFluentImpl.StatusNestedImpl();
  }
  public JVMChaosFluentImpl.StatusNested<A> withNewStatusLike(JVMChaosStatus item) {
    return new JVMChaosFluentImpl.StatusNestedImpl(item);
  }
  public JVMChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public JVMChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new JVMChaosStatusBuilder().build());
  }
  public JVMChaosFluentImpl.StatusNested<A> editOrNewStatusLike(JVMChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMChaosFluentImpl that = (JVMChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<JVMChaosFluentImpl.MetadataNested<N>> implements JVMChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) JVMChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends JVMChaosSpecFluentImpl<JVMChaosFluentImpl.SpecNested<N>> implements JVMChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(JVMChaosSpec item) {
      this.builder = new JVMChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new JVMChaosSpecBuilder(this);
    }
    JVMChaosSpecBuilder builder;
    public N and() {
      return (N) JVMChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends JVMChaosStatusFluentImpl<JVMChaosFluentImpl.StatusNested<N>> implements JVMChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(JVMChaosStatus item) {
      this.builder = new JVMChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new JVMChaosStatusBuilder(this);
    }
    JVMChaosStatusBuilder builder;
    public N and() {
      return (N) JVMChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
